@@ -1,10 +1,11 @@
 package Data::ModeMerge::Mode::NORMAL;
 BEGIN {
-  $Data::ModeMerge::Mode::NORMAL::VERSION = '0.24';
+  $Data::ModeMerge::Mode::NORMAL::VERSION = '0.25';
 }
 # ABSTRACT: Handler for Data::ModeMerge NORMAL merge mode
 
 
+use 5.010;
 use Any::Moose;
 extends 'Data::ModeMerge::Mode::Base';
 
@@ -99,7 +100,7 @@ Data::ModeMerge::Mode::NORMAL - Handler for Data::ModeMerge NORMAL merge mode
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -109,9 +110,11 @@ version 0.24
 
 This is the class to handle NORMAL merge mode.
 
+=for Pod::Coverage ^merge_.*
+
 =head1 AUTHOR
 
-  Steven Haryanto <stevenharyanto@gmail.com>
+Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
